===================
Networking Scenario
===================

.. toctree::
    :maxdepth: 3

    networking-guide-direct-provider-networks.rst
    networking-guide-multiple-external-networks.rst
    networking-guide-single-external-network.rst
    networking-guide-local-networking.rst
